@@ -27,12 +27,30 @@ checkQualtricsDuplicates <- function(measure_alias, measure_type, verbose = TRUE
   # Generate the name of the dataframe and get it
   output_df_name <- paste0(measure_alias, "_clean")
   df <- base::get(output_df_name)
-
-  identifier <- "src_subject_id"
+  
+  # possible identifiers
+  possible_identifiers <- c("src_subject_id", "workerId", "PROLIFIC_PID", "participantId")
 
   if (measure_type == "qualtrics") {
-    if (!(identifier %in% colnames(df))) {
-      stop("Please provide a valid identifier: src_subject_id, workerId, PROLIFIC_PID")
+    # Find which identifiers exist in the dataframe
+    existing_identifiers <- possible_identifiers[possible_identifiers %in% colnames(df)]
+    
+    if (length(existing_identifiers) == 0) {
+      stop("Please provide valid identifiers: src_subject_id, workerId, PROLIFIC_PID, participantId")
+    }
+    
+    # Find the first identifier with non-NA values
+    identifier <- NA
+    for (key in existing_identifiers) {
+      non_na_count <- sum(!is.na(df[[key]]))
+      if (non_na_count > 0) {
+        identifier <- key
+        break
+      }
+    }
+    
+    if (is.na(identifier)) {
+      stop(paste("No identifier found with non-NA values. Available identifiers:", paste(existing_identifiers, collapse = ", ")))
     }
 
     for (col in c("visit", "week")) {
@@ -50,17 +68,17 @@ checkQualtricsDuplicates <- function(measure_alias, measure_type, verbose = TRUE
             duplicate_extract <- paste0("duplicates_", measure_alias)
             createCsv(df_duplicates, paste0("duplicates_", measure_alias))
 
+            duplicates_summary <- toString(base::unique(df_duplicates[[identifier]]))
+            error_msg <- paste("DATA ERROR: Duplicates detected in '", measure_alias, "': ",
+                              "Offending IDs: ", duplicates_summary,
+                              "\nDetails exported to ", paste0("./tmp/",duplicate_extract,".csv"))
+            
             tryCatch({
               testthat::test_that("Check for Qualtrics duplicates", {
-                testthat::expect_true(base::nrow(df_duplicates) == 0,
-                                      info = paste("DATA ERROR: Duplicates detected in '", measure_alias, "': ",
-                                                   "Offending IDs: ", toString(base::unique(df_duplicates[[identifier]]))))
+                testthat::expect_true(FALSE, info = error_msg)
               })
             }, error = function(e) {
-              duplicates_summary <- toString(base::unique(df_duplicates[[identifier]]))
-              message(paste("Error in testing for duplicates in '", measure_alias, "': ", e$message,
-                            "\nOffending IDs: ", duplicates_summary,
-                            "\nDetails exported to ", paste0("./tmp/",duplicate_extract,".csv")))
+              message(error_msg)
             })
 
             # Optionally view the offending records in RStudio's data viewer
