@@ -76,7 +76,8 @@ formatDuration <- function(duration) {
 #'        in ALL specified columns will be returned. This is useful for filtering
 #'        data to only include complete cases for specific variables of interest.
 #' @param raw_or_label Whether to return raw or labeled values
-#' @param redcap_event_name Optional event name filter
+#' @param redcap_event_name Optional event name filter. Can be a single string
+#'        or a vector of event names (e.g., \code{c("event1", "event2")})
 #' @param batch_size Number of records to retrieve per batch
 #' @param records Optional vector of specific record IDs
 #' @param fields Optional vector of specific fields
@@ -142,6 +143,20 @@ redcap <- function(instrument_name = NULL, ..., raw_or_label = "raw",
     "int_end"
   )
 
+  # Validate and normalize redcap_event_name parameter
+  if (!is.null(redcap_event_name)) {
+    # Convert to character vector if it's not already
+    if (!is.character(redcap_event_name)) {
+      stop("redcap_event_name must be a character vector or NULL")
+    }
+    # Remove any NA values and trim whitespace
+    redcap_event_name <- trimws(redcap_event_name[!is.na(redcap_event_name)])
+    # If after filtering we have an empty vector, set to NULL
+    if (length(redcap_event_name) == 0) {
+      redcap_event_name <- NULL
+    }
+  }
+
   # Validate date_format parameter
   if (!date_format %in% c("mdy", "dmy", "ymd")) {
     stop("date_format must be one of 'mdy', 'dmy', or 'ymd'")
@@ -289,11 +304,18 @@ redcap <- function(instrument_name = NULL, ..., raw_or_label = "raw",
 
   # Progress bar
   pb <- initializeLoadingAnimation(20)
+  event_name_display <- if (!is.null(redcap_event_name)) {
+    if (length(redcap_event_name) == 1) {
+      sprintf(" %s", redcap_event_name)
+    } else {
+      sprintf(" [%s]", paste(redcap_event_name, collapse = ", "))
+    }
+  } else {
+    ""
+  }
   message(sprintf("\nImporting records from REDCap form: %s%s%s",
                   instrument_name,
-                  ifelse(!is.null(redcap_event_name),
-                         sprintf(" %s", redcap_event_name),
-                         ""),
+                  event_name_display,
                  ifelse(!pii && length(pii_fields) > 0, " (excluding PII)", "")))
   for (i in 1:20) {
     updateLoadingAnimation(pb, i)
@@ -309,6 +331,7 @@ redcap <- function(instrument_name = NULL, ..., raw_or_label = "raw",
     forms = config$redcap$superkey,
     batch_size = batch_size,
     records = records,
+    events = redcap_event_name,  # Filter by event names if specified
     raw_or_label = "label",  # Always use label for superkey
     raw_or_label_headers = "raw",
     verbose = FALSE
@@ -321,6 +344,7 @@ redcap <- function(instrument_name = NULL, ..., raw_or_label = "raw",
     forms = instrument_name,
     batch_size = batch_size,
     records = records,
+    events = redcap_event_name,  # Filter by event names if specified
     fields = selected_fields,
     raw_or_label = raw_or_label,  # Use user's preference
     raw_or_label_headers = "raw",
@@ -582,7 +606,8 @@ redcap <- function(instrument_name = NULL, ..., raw_or_label = "raw",
     if (!"redcap_event_name" %in% names(df)) {
       stop("Cannot filter by redcap_event_name: column not found in data")
     }
-    df <- df[df$redcap_event_name == redcap_event_name, ]
+    # Use %in% to support both single strings and vectors
+    df <- df[df$redcap_event_name %in% redcap_event_name, ]
   }
 
   # Study-specific processing (legacy - errors should be fixed in redcap...)
@@ -865,7 +890,6 @@ redcap.dict <- function(instrument_name) {
   # Check if input is a data frame with redcap_instrument attribute
   if (is.data.frame(instrument_name) && !is.null(attr(instrument_name, "redcap_instrument"))) {
     inst <- attr(instrument_name, "redcap_instrument")
-    message(sprintf("Retrieving metadata for instrument '%s' from data frame attributes.", inst))
 
     # Fetch metadata using the instrument name
     # Validate secrets
